@@ -2,7 +2,7 @@ package Algorithm::Evolutionary;
 
 use Carp qw(croak);
 
-our $VERSION = '0.78'; # Another year in paradise
+our $VERSION = '0.79'; # Getting close to something
 
 # Preloaded methods go here.
 
@@ -32,6 +32,8 @@ sub import {
 1;
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 Algorithm::Evolutionary - Perl module for performing paradigm-free evolutionary algorithms. 
@@ -89,7 +91,7 @@ site</a>).</p>
 <p>It might be also helpful for you to check out <a
 href='http://arxiv.org/abs/0908.0516'>Still doing evolutionary
 algorithms with Perl</a>, a gentle introduction to evolutionary
-algorithms in general and doing them using this module in particular.</p>
+algorithms in general and working with them using this module in particular.</p>
 
 <p>I have used this continously for my research all these year, and
 any search will return a number of papers; a journal article is
@@ -101,8 +103,8 @@ research, I would be very grateful if you quoted papers such as these
 =end html
 
  @article {springerlink:10.1007/s00500-009-0504-3,
-   author = {Merelo Guervs, Juan-Julin and Castillo, Pedro and Alba, Enrique},
-   affiliation = {Universidad de Granada Depto. Arquitectura y Tecnologa de Computadores, ETS Ingenieras Informtica y Telecomunicaciones Granada Spain},
+   author = {Merelo Guervós, Juan-Julián and Castillo, Pedro and Alba, Enrique},
+   affiliation = {Universidad de Granada Depto. Arquitectura y Tecnología de Computadores, ETS Ingenierías Informática y Telecomunicaciones Granada Spain},
    title = {Algorithm::Evolutionary, a flexible Perl module for evolutionary computation},
    journal = {Soft Computing - A Fusion of Foundations, Methodologies and Applications},
    publisher = {Springer Berlin / Heidelberg},
@@ -119,7 +121,7 @@ research, I would be very grateful if you quoted papers such as these
  @InProceedings{jj:2008:PPSN,
    author =	"Juan J. Merelo and  Antonio M. Mora and Pedro A. Castillo
                  and Juan L. J. Laredo and Lourdes Araujo and Ken C. Sharman
-                 and Anna I. Esparcia-Alczar and Eva Alfaro-Cid
+                 and Anna I. Esparcia-Alcázar and Eva Alfaro-Cid
                  and Carlos Cotta",
    title =	"Testing the Intermediate Disturbance Hypothesis: Effect of
                  Asynchronous Population Incorporation on Multi-Deme
@@ -167,7 +169,9 @@ Some other examples are installed: check out L<tide_bitstring.pl>,
     like, and then ammend, add and modify at leisure to create your
     own evolutionary algorithms. For a GUI example, check
     L<rectangle-coverage.pl>, which uses L<Tk> to show the population
-    and its evolution.
+    and its evolution. You will need to install the required modules,
+    however, since it needs additional ones to those required by this
+    module. 
 
 
 =head1 DISCUSSION, FEATURE REQUESTS
@@ -190,18 +194,28 @@ Main author and developer is J. J. Merelo, jmerelo (at) geneura.ugr.es
 who blogs at <a href='http://blojj.blogalia.com'>BloJJ</a> and
 twitters at <a
 href='http://twitter.com/jjmerelo'>twitter.com/jjmerelo</a>. There have
-also been some contributions from Javi Garca, fjgc (at) decsai.ugr.es
-and Pedro Castillo, pedro (at) geneura.ugr.es. Patient users that have
-submitted bugs include <a
-href='http://barbacana.net'>jamarier</a>, <a href='http://leandrohermida.com'>Leandro Hermida</a>, Jrme Qulin  and Mike Gajewski. <a href='http://alexm.org'>Alex Muntada</a>,
-from the <a href='http://barcelona.pm.org/'>Barcelona Perl
-Mongers</a>, helped me solve a problem with the Makefile.PL. Bug reports (and patches), requests and any kind 
+also been some contributions from Javi García, fjgc (at) decsai.ugr.es
+and Pedro Castillo, pedro (at) geneura.ugr.es. 
+
+Patient users that have submitted bugs include <a
+href='http://barbacana.net'>jamarier</a>, <a
+href='http://leandrohermida.com'>Leandro Hermida</a>, Jérôme Quélin
+Mike Gajewski and Cristoph Meissner. <a href='http://alexm.org'>Alex
+Muntada</a>, from the <a href='http://barcelona.pm.org/'>Barcelona
+Perl Mongers</a>, helped me solve a problem with the Makefile.PL.
+
+Bug reports (and patches), requests and any kind 
 of comment are welcome.
 
 =end html
 
 =head1 SEE ALSO
 
+If you are just looking for a plain vanilla genetic algorithm for
+didactic purposes, check also L<Algorithm::Evolutionary::Simple>,
+which does the job in a straight fashion and can be used easily for
+demos or adapting it to external fitness functions. 
+
 =over
 
 =item L<Algorithm::Evolutionary::Op::Base>.
@@ -238,9 +252,4 @@ L<AI::Genetic::Pro>.
 This file is released under the GPL. See the LICENSE file included in this distribution,
 or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2011/11/30 17:33:25 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary.pm,v 3.19 2011/11/30 17:33:25 jmerelo Exp $ 
-  $Author: jmerelo $ 
-  $Revision: 3.19 $
-
 =cut
